@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,24 +49,23 @@
 
 package com.openexchange.oauth.json.oauthaccount.actions;
 
-import java.io.IOException;
+import static com.openexchange.java.Strings.isEmpty;
 import java.io.UnsupportedEncodingException;
+import java.net.InetAddress;
 import java.net.URLEncoder;
+import java.net.UnknownHostException;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.UUID;
-import javax.servlet.http.HttpServletResponse;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
-import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
-import com.openexchange.ajax.requesthandler.AJAXRequestResult.ResultType;
 import com.openexchange.documentation.RequestMethod;
 import com.openexchange.documentation.annotations.Action;
 import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
-import com.openexchange.java.StringAllocator;
+import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthConstants;
 import com.openexchange.oauth.OAuthExceptionCodes;
@@ -75,6 +74,7 @@ import com.openexchange.oauth.OAuthService;
 import com.openexchange.oauth.OAuthToken;
 import com.openexchange.oauth.Parameterizable;
 import com.openexchange.oauth.json.AbstractOAuthAJAXActionService;
+import com.openexchange.oauth.json.Services;
 import com.openexchange.oauth.json.Tools;
 import com.openexchange.oauth.json.oauthaccount.AccountField;
 import com.openexchange.oauth.json.oauthaccount.AccountWriter;
@@ -122,100 +122,78 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
     //FIXME: Refactor this. These methods are pretty similar. DRY
 
     private AJAXRequestResult createCallbackAction(final AJAXRequestData request, final ServerSession session) throws OXException, JSONException {
-        try {
-            final OAuthService oAuthService = getOAuthService();
-            /*
-             * Parse parameters
-             */
-            final String serviceId = request.getParameter(AccountField.SERVICE_ID.getName());
-            if (serviceId == null) {
-                throw AjaxExceptionCodes.MISSING_PARAMETER.create( AccountField.SERVICE_ID.getName());
-            }
-            final String name = AccountField.DISPLAY_NAME.getName();
-            final String displayName = request.getParameter(name);
-            if (isEmpty(displayName)) {
-                throw OAuthExceptionCodes.MISSING_DISPLAY_NAME.create();
-            }
-            /*
-             * Generate UUID
-             */
-            final String uuid = UUID.randomUUID().toString();
-            /*
-             * OAuth token for session
-             */
-            final String oauthSessionToken = UUID.randomUUID().toString();
-            /*
-             * Compose call-back URL
-             */
-            final String callbackUrl;
-            {
-                final StringBuilder callbackUrlBuilder = request.constructURL(new StringBuilder(PREFIX.get().getPrefix()).append("oauth/accounts").toString(), true);
-                // Append query string
-                callbackUrlBuilder.append("?action=create");
-                callbackUrlBuilder.append("&respondWithHTML=true&session=").append(session.getSessionID());
-                callbackUrlBuilder.append('&').append(name).append('=').append(urlEncode(displayName));
-                callbackUrlBuilder.append('&').append(AccountField.SERVICE_ID.getName()).append('=').append(urlEncode(serviceId));
-                callbackUrlBuilder.append('&').append(OAuthConstants.SESSION_PARAM_UUID).append('=').append(uuid);
-                callbackUrlBuilder.append('&').append(Session.PARAM_TOKEN).append('=').append(oauthSessionToken);
-                final String cb = request.getParameter("cb");
-                if (!isEmpty(cb)) {
-                	callbackUrlBuilder.append("&callback=").append(cb);
-                }
-                callbackUrl = callbackUrlBuilder.toString();
-            }
-            /*
-             * Invoke
-             */
-            final OAuthInteraction interaction = oAuthService.initOAuth(serviceId, callbackUrl, session);
-            final OAuthToken requestToken = interaction.getRequestToken();
-            /*
-             * Create a container to set some state information: Request token's secret, call-back URL, whatever
-             */
-            final Map<String, Object> oauthState = new HashMap<String, Object>();
-            if (interaction instanceof Parameterizable) {
-                final Parameterizable params = (Parameterizable) interaction;
-                for (final String key : params.getParamterNames()) {
-                    final Object value = params.getParameter(key);
-                    if (null != value) {
-                        oauthState.put(key, value);
-                    }
-                }
-            }
-            oauthState.put(OAuthConstants.ARGUMENT_SECRET, requestToken.getSecret());
-            oauthState.put(OAuthConstants.ARGUMENT_CALLBACK, callbackUrl);
-            session.setParameter(uuid, oauthState);
-            session.setParameter(Session.PARAM_TOKEN, oauthSessionToken);
-            /*
-             * Check redirect parameter
-             */
-            if (AJAXRequestDataTools.parseBoolParameter(request.getParameter("redirect"))) {
-                // Request for redirect
-                HttpServletResponse response = request.optHttpServletResponse();
-                if (null != response) {
-                    try {
-                        response.sendRedirect(interaction.getAuthorizationURL());
-                        //response.setStatus(HttpServletResponse.SC_MOVED_TEMPORARILY);
-                        return new AJAXRequestResult(AJAXRequestResult.DIRECT_OBJECT, "direct").setType(ResultType.DIRECT);
-                    } catch (IOException e) {
-                        throw OAuthExceptionCodes.IO_ERROR.create(e, e.getMessage());
-                    }
-                }
-            }
-            /*
-             * Write as JSON
-             */
-            final JSONObject jsonInteraction = AccountWriter.write(interaction, uuid);
-            /*
-             * Return appropriate result
-             */
-            return new AJAXRequestResult(jsonInteraction);
-        } catch (OXException e) {
-            throw AjaxExceptionCodes.HTTP_ERROR.create(e, HttpServletResponse.SC_OK, e.getMessage());
-        } catch (JSONException e) {
-            throw AjaxExceptionCodes.HTTP_ERROR.create(e, HttpServletResponse.SC_OK, e.getMessage());
-        } catch (RuntimeException e) {
-            throw AjaxExceptionCodes.HTTP_ERROR.create(e, HttpServletResponse.SC_OK, e.getMessage());
+        final OAuthService oAuthService = getOAuthService();
+        /*
+         * Parse parameters
+         */
+        final String serviceId = request.getParameter(AccountField.SERVICE_ID.getName());
+        if (serviceId == null) {
+            throw AjaxExceptionCodes.MISSING_PARAMETER.create( AccountField.SERVICE_ID.getName());
         }
+        final String name = AccountField.DISPLAY_NAME.getName();
+        final String displayName = request.getParameter(name);
+        if (isEmpty(displayName)) {
+            throw OAuthExceptionCodes.MISSING_DISPLAY_NAME.create();
+        }
+        /*
+         * Generate UUID
+         */
+        final String uuid = UUID.randomUUID().toString();
+        /*
+         * OAuth token for session
+         */
+        final String oauthSessionToken = UUID.randomUUID().toString();
+        /*
+         * Compose call-back URL
+         */
+        final String callbackUrl;
+        {
+            final StringBuilder callbackUrlBuilder = request.constructURL(new StringBuilder(PREFIX.get().getPrefix()).append("oauth/accounts").toString(), true);
+            // Append query string
+            callbackUrlBuilder.append("?action=create");
+            callbackUrlBuilder.append("&respondWithHTML=true&session=").append(session.getSessionID());
+            callbackUrlBuilder.append('&').append(name).append('=').append(urlEncode(displayName));
+            callbackUrlBuilder.append('&').append(AccountField.SERVICE_ID.getName()).append('=').append(urlEncode(serviceId));
+            callbackUrlBuilder.append('&').append(OAuthConstants.SESSION_PARAM_UUID).append('=').append(uuid);
+            callbackUrlBuilder.append('&').append(Session.PARAM_TOKEN).append('=').append(oauthSessionToken);
+            final String cb = request.getParameter("cb");
+            if (!isEmpty(cb)) {
+            	callbackUrlBuilder.append("&callback=").append(cb);
+            }
+            callbackUrl = callbackUrlBuilder.toString();
+        }
+        /*
+         * Invoke
+         */
+        final String currentHost = determineHost(request, session);
+        final OAuthInteraction interaction = oAuthService.initOAuth(serviceId, callbackUrl, currentHost, session);
+        final OAuthToken requestToken = interaction.getRequestToken();
+        /*
+         * Create a container to set some state information: Request token's secret, call-back URL, whatever
+         */
+        final Map<String, Object> oauthState = new HashMap<String, Object>();
+        if (interaction instanceof Parameterizable) {
+            final Parameterizable params = (Parameterizable) interaction;
+            for (final String key : params.getParamterNames()) {
+                final Object value = params.getParameter(key);
+                if (null != value) {
+                    oauthState.put(key, value);
+                }
+            }
+        }
+        oauthState.put(OAuthConstants.ARGUMENT_SECRET, requestToken.getSecret());
+        oauthState.put(OAuthConstants.ARGUMENT_CALLBACK, callbackUrl);
+        oauthState.put(OAuthConstants.ARGUMENT_CURRENT_HOST, currentHost);
+        session.setParameter(uuid, oauthState);
+        session.setParameter(Session.PARAM_TOKEN, oauthSessionToken);
+        /*
+         * Write as JSON
+         */
+        final JSONObject jsonInteraction = AccountWriter.write(interaction, uuid);
+        /*
+         * Return appropriate result
+         */
+        return new AJAXRequestResult(jsonInteraction);
     }
 
     private AJAXRequestResult reauthorizeCallbackAction(final String accountId, final AJAXRequestData request, final ServerSession session) throws OXException, JSONException {
@@ -236,7 +214,7 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
         /*
          * Compose call-back URL
          */
-        final StringBuilder callbackUrlBuilder = request.constructURL(new StringAllocator(PREFIX.get().getPrefix()).append("oauth/accounts").toString(), true);
+        final StringBuilder callbackUrlBuilder = request.constructURL(new StringBuilder(PREFIX.get().getPrefix()).append("oauth/accounts").toString(), true);
         callbackUrlBuilder.append("?action=reauthorize");
         callbackUrlBuilder.append("&id=").append(account.getId());
         callbackUrlBuilder.append("&respondWithHTML=true&session=").append(session.getSessionID());
@@ -257,7 +235,7 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
         /*
          * Invoke
          */
-        final OAuthInteraction interaction = oAuthService.initOAuth(serviceId, callbackUrlBuilder.toString(), session);
+        final OAuthInteraction interaction = oAuthService.initOAuth(serviceId, callbackUrlBuilder.toString(), determineHost(request, session), session);
         final OAuthToken requestToken = interaction.getRequestToken();
         /*
          * Create a container to set some state information: Request token's secret, call-back URL, whatever
@@ -267,22 +245,6 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
         oauthState.put(OAuthConstants.ARGUMENT_CALLBACK, callbackUrlBuilder.toString());
         session.setParameter(uuid, oauthState);
         session.setParameter(Session.PARAM_TOKEN, oauthSessionToken);
-        /*
-         * Check redirect parameter
-         */
-        if (AJAXRequestDataTools.parseBoolParameter(request.getParameter("redirect"))) {
-            // Request for redirect
-            HttpServletResponse response = request.optHttpServletResponse();
-            if (null != response) {
-                try {
-                    response.sendRedirect(interaction.getAuthorizationURL());
-                    //response.setStatus(HttpServletResponse.SC_MOVED_TEMPORARILY);
-                    return new AJAXRequestResult(AJAXRequestResult.DIRECT_OBJECT, "direct").setType(ResultType.DIRECT);
-                } catch (IOException e) {
-                    throw OAuthExceptionCodes.IO_ERROR.create(e, e.getMessage());
-                }
-            }
-        }
         /*
          * Write as JSON
          */
@@ -301,17 +263,40 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
         }
     }
 
-    /** Checks for an empty string */
-    private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
+    private static String determineHost(AJAXRequestData requestData, ServerSession session) {
+        String hostName = null;
+        /*
+         * Ask hostname service if available
+         */
+        {
+            final HostnameService hostnameService = Services.getService(HostnameService.class);
+            if (null != hostnameService) {
+                hostName = hostnameService.getHostname(session.getUserId(), session.getContextId());
+            }
         }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
+        /*
+         * Get hostname from request
+         */
+        if (isEmpty(hostName)) {
+            hostName = requestData.getHostname();
         }
-        return isWhitespace;
+        /*
+         * Get hostname from java
+         */
+        if (isEmpty(hostName)) {
+            try {
+                hostName = InetAddress.getLocalHost().getCanonicalHostName();
+            } catch (UnknownHostException e) {
+                // ignore
+            }
+        }
+        /*
+         * Fall back to localhost as last resort
+         */
+        if (isEmpty(hostName)) {
+            hostName = "localhost";
+        }
+        return requestData.getHostname();
     }
 
 }
