@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,6 +59,7 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.concurrent.TimeUnit;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -135,6 +136,8 @@ public class LinkedInServiceImpl implements LinkedInService {
 
         final Token accessToken = new Token(account.getToken(), account.getSecret());
         final OAuthRequest request = new OAuthRequest(method, url);
+        request.setConnectTimeout(5, TimeUnit.SECONDS);
+        request.setReadTimeout(30, TimeUnit.SECONDS);
         service.signRequest(accessToken, request);
         return request.send();
     }
