@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,8 +49,12 @@
 
 package com.openexchange.oauth.yahoo.internal;
 
+import java.util.HashMap;
+import java.util.Map;
 import org.scribe.builder.api.Api;
 import org.scribe.builder.api.YahooApi;
+import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Reloadable;
 import com.openexchange.http.deferrer.DeferringURLService;
 import com.openexchange.oauth.API;
 import com.openexchange.oauth.AbstractOAuthServiceMetaData;
@@ -62,12 +66,14 @@ import com.openexchange.session.Session;
  * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public class OAuthServiceMetaDataYahooImpl extends AbstractOAuthServiceMetaData implements com.openexchange.oauth.ScribeAware {
-    
+public class OAuthServiceMetaDataYahooImpl extends AbstractOAuthServiceMetaData implements com.openexchange.oauth.ScribeAware, Reloadable {
+
     private static final String API_KEY = "com.openexchange.oauth.yahoo.apiKey";
 
     private static final String API_SECRET = "com.openexchange.oauth.yahoo.apiSecret";
-    
+
+    private static final String[] PROPERTIES = new String[] {API_KEY, API_SECRET};
+
     private final DeferringURLService deferrer;
 
     public OAuthServiceMetaDataYahooImpl(DeferringURLService deferrer) {
@@ -80,7 +86,7 @@ public class OAuthServiceMetaDataYahooImpl extends AbstractOAuthServiceMetaData
     }
 
     @Override
-    public String modifyCallbackURL(String callbackUrl, Session session) {
+    public String modifyCallbackURL(String callbackUrl, String currentHost, Session session) {
         if (deferrer == null) {
             return callbackUrl;
         }
@@ -96,4 +102,27 @@ public class OAuthServiceMetaDataYahooImpl extends AbstractOAuthServiceMetaData
     public Class<? extends Api> getScribeService() {
         return YahooApi.class;
     }
+
+    @Override
+    public void reloadConfiguration(ConfigurationService configService) {
+        String apiKey = configService.getProperty(apiKeyName);
+        String secretKey = configService.getProperty(apiSecretName);
+
+        if (apiKey.isEmpty()) {
+            throw new IllegalStateException("Missing following property in configuration: " + apiKeyName);
+        }
+        if (secretKey.isEmpty()) {
+            throw new IllegalStateException("Missing following property in configuration: " + apiSecretName);
+        }
+
+        this.apiKey = apiKey;
+        this.apiSecret = secretKey;
+    }
+
+    @Override
+    public Map<String, String[]> getConfigFileNames() {
+        Map<String, String[]> map = new HashMap<String, String[]>(1);
+        map.put("yahoooauth.properties", PROPERTIES);
+        return map;
+    }
 }
