@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -87,11 +87,11 @@ public interface OAuthServiceMetaData {
     boolean isEnabled(int userId, int contextId) throws OXException;
 
     /**
-     * Gets the API key.
+     * Use {@link #getAPIKey(Session)} and also please implement {@link #getAPIKey(Session)}
      *
-     * @depcrecated: Please use {@link #getAPIKey(Session)} and also please implement {@link #getAPIKey(Session)}
      * @return The API key
      */
+    @Deprecated
     String getAPIKey();
 
     /**
@@ -103,11 +103,10 @@ public interface OAuthServiceMetaData {
     String getAPIKey(Session session) throws OXException;
 
     /**
-     * Gets the API secret.
-     *
-     * @deprecated: Use {@link #getAPISecret(Session)} and also implement {@link #getAPISecret(Session)}
+     * Use {@link #getAPISecret(Session)} and also implement {@link #getAPISecret(Session)}
      * @return The API secret
      */
+    @Deprecated
     String getAPISecret();
 
     /**
@@ -118,6 +117,18 @@ public interface OAuthServiceMetaData {
      */
     String getAPISecret(Session session) throws OXException;
 
+    /**
+     * Get the consumer key (upsell)
+     * @return the consumer key
+     */
+    String getConsumerKey();
+
+    /**
+     * Get the consumer secret (upsell)
+     * @return the consumer secret
+     */
+    String getConsumerSecret();
+
     /**
      * Indicates if this meta data needs a request token to obtain authorization URL.
      *
@@ -180,11 +191,13 @@ public interface OAuthServiceMetaData {
 
     /**
      * Gives the strategy the opportunity to modify a callback URL.
-     * @param callbackUrl
-     * @param session
+     *
+     * @param callbackUrl The call-back URL
+     * @param currentHost The name of the current host
+     * @param session The associated session
      * @return the modified callback URL
      */
-    String modifyCallbackURL(String callbackUrl, Session session);
+    String modifyCallbackURL(String callbackUrl, String currentHost, Session session);
 
     /**
      * Gets the style of API (e.g. Facebook, Twitter...).
